// Copyright (C) 2022 - 2023, Xilinx Inc - All rights reserved
//
// Licensed under the Apache License, Version 2.0 (the "License"). You may
// not use this file except in compliance with the License. A copy of the
// License is located at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations
// under the License.

#ifndef _XRM_INTERFACE_H_
#define _XRM_INTERFACE_H_

#ifdef __cplusplus
extern "C" {
#endif

typedef struct XrmInterfaceProperties {
  int      width;
  int      height;
  int      fps_num;
  int      fps_den;
  bool     is_la_enabled;
  uint32_t enc_cores;       // defaults to 1-core encoding
  char     preset[16];      // default value is "medium"
  char     model[64];       // TODO : Refine the size
  char     model_args[512]; // TODO : Refine the size
} XrmInterfaceProperties;

/**
 * @brief Get the device index using the XRM_RESERVE_ID environment variable.
 *
 * @return The device index corresponding to XRM_RESERVE_ID, 0 if unset, or
 * XRM_ERROR on error
 */
int xrm_interface_get_dev_index(void);

#ifdef __cplusplus
}
#endif

#endif // _XRM_INTERFACE_H_
